from _typeshed import Incomplete

class Axes:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, x: Incomplete | None = None, y: Incomplete | None = None) -> None: ...
    @property
    def x(self): ...
    @x.setter
    def x(self, x) -> None: ...
    @property
    def y(self): ...
    @y.setter
    def y(self, y) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
