from _typeshed import Incomplete

class MetadataBackup:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, kv: Incomplete | None = None, sql: Incomplete | None = None, buckets: Incomplete | None = None
    ) -> None: ...
    @property
    def kv(self): ...
    @kv.setter
    def kv(self, kv) -> None: ...
    @property
    def sql(self): ...
    @sql.setter
    def sql(self, sql) -> None: ...
    @property
    def buckets(self): ...
    @buckets.setter
    def buckets(self, buckets) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
