from _typeshed import Incomplete

class RenamableField:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, internal_name: Incomplete | None = None, display_name: Incomplete | None = None, visible: Incomplete | None = None
    ) -> None: ...
    @property
    def internal_name(self): ...
    @internal_name.setter
    def internal_name(self, internal_name) -> None: ...
    @property
    def display_name(self): ...
    @display_name.setter
    def display_name(self, display_name) -> None: ...
    @property
    def visible(self): ...
    @visible.setter
    def visible(self, visible) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
