from _typeshed import Incomplete

class TableViewPropertiesTableOptions:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        vertical_time_axis: Incomplete | None = None,
        sort_by: Incomplete | None = None,
        wrapping: Incomplete | None = None,
        fix_first_column: Incomplete | None = None,
    ) -> None: ...
    @property
    def vertical_time_axis(self): ...
    @vertical_time_axis.setter
    def vertical_time_axis(self, vertical_time_axis) -> None: ...
    @property
    def sort_by(self): ...
    @sort_by.setter
    def sort_by(self, sort_by) -> None: ...
    @property
    def wrapping(self): ...
    @wrapping.setter
    def wrapping(self, wrapping) -> None: ...
    @property
    def fix_first_column(self): ...
    @fix_first_column.setter
    def fix_first_column(self, fix_first_column) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
