from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class TelegrafsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_telegrafs_id(self, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_with_http_info(self, telegraf_id, **kwargs): ...
    async def delete_telegrafs_id_async(self, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_labels_id(self, telegraf_id, label_id, **kwargs): ...
    def delete_telegrafs_id_labels_id_with_http_info(self, telegraf_id, label_id, **kwargs): ...
    async def delete_telegrafs_id_labels_id_async(self, telegraf_id, label_id, **kwargs): ...
    def delete_telegrafs_id_members_id(self, user_id, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_members_id_with_http_info(self, user_id, telegraf_id, **kwargs): ...
    async def delete_telegrafs_id_members_id_async(self, user_id, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_owners_id(self, user_id, telegraf_id, **kwargs): ...
    def delete_telegrafs_id_owners_id_with_http_info(self, user_id, telegraf_id, **kwargs): ...
    async def delete_telegrafs_id_owners_id_async(self, user_id, telegraf_id, **kwargs): ...
    def get_telegrafs(self, **kwargs): ...
    def get_telegrafs_with_http_info(self, **kwargs): ...
    async def get_telegrafs_async(self, **kwargs): ...
    def get_telegrafs_id(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_async(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_labels(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_labels_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_labels_async(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_members(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_members_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_members_async(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_owners(self, telegraf_id, **kwargs): ...
    def get_telegrafs_id_owners_with_http_info(self, telegraf_id, **kwargs): ...
    async def get_telegrafs_id_owners_async(self, telegraf_id, **kwargs): ...
    def post_telegrafs(self, telegraf_plugin_request, **kwargs): ...
    def post_telegrafs_with_http_info(self, telegraf_plugin_request, **kwargs): ...
    async def post_telegrafs_async(self, telegraf_plugin_request, **kwargs): ...
    def post_telegrafs_id_labels(self, telegraf_id, label_mapping, **kwargs): ...
    def post_telegrafs_id_labels_with_http_info(self, telegraf_id, label_mapping, **kwargs): ...
    async def post_telegrafs_id_labels_async(self, telegraf_id, label_mapping, **kwargs): ...
    def post_telegrafs_id_members(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def post_telegrafs_id_members_with_http_info(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    async def post_telegrafs_id_members_async(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def post_telegrafs_id_owners(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def post_telegrafs_id_owners_with_http_info(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    async def post_telegrafs_id_owners_async(self, telegraf_id, add_resource_member_request_body, **kwargs): ...
    def put_telegrafs_id(self, telegraf_id, telegraf_plugin_request, **kwargs): ...
    def put_telegrafs_id_with_http_info(self, telegraf_id, telegraf_plugin_request, **kwargs): ...
    async def put_telegrafs_id_async(self, telegraf_id, telegraf_plugin_request, **kwargs): ...
