from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class HistogramViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        queries: Incomplete | None = None,
        colors: Incomplete | None = None,
        shape: Incomplete | None = None,
        note: Incomplete | None = None,
        show_note_when_empty: Incomplete | None = None,
        x_column: Incomplete | None = None,
        fill_columns: Incomplete | None = None,
        x_domain: Incomplete | None = None,
        x_axis_label: Incomplete | None = None,
        position: Incomplete | None = None,
        bin_count: Incomplete | None = None,
        legend_colorize_rows: Incomplete | None = None,
        legend_hide: Incomplete | None = None,
        legend_opacity: Incomplete | None = None,
        legend_orientation_threshold: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def queries(self): ...
    @queries.setter
    def queries(self, queries) -> None: ...
    @property
    def colors(self): ...
    @colors.setter
    def colors(self, colors) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def note(self): ...
    @note.setter
    def note(self, note) -> None: ...
    @property
    def show_note_when_empty(self): ...
    @show_note_when_empty.setter
    def show_note_when_empty(self, show_note_when_empty) -> None: ...
    @property
    def x_column(self): ...
    @x_column.setter
    def x_column(self, x_column) -> None: ...
    @property
    def fill_columns(self): ...
    @fill_columns.setter
    def fill_columns(self, fill_columns) -> None: ...
    @property
    def x_domain(self): ...
    @x_domain.setter
    def x_domain(self, x_domain) -> None: ...
    @property
    def x_axis_label(self): ...
    @x_axis_label.setter
    def x_axis_label(self, x_axis_label) -> None: ...
    @property
    def position(self): ...
    @position.setter
    def position(self, position) -> None: ...
    @property
    def bin_count(self): ...
    @bin_count.setter
    def bin_count(self, bin_count) -> None: ...
    @property
    def legend_colorize_rows(self): ...
    @legend_colorize_rows.setter
    def legend_colorize_rows(self, legend_colorize_rows) -> None: ...
    @property
    def legend_hide(self): ...
    @legend_hide.setter
    def legend_hide(self, legend_hide) -> None: ...
    @property
    def legend_opacity(self): ...
    @legend_opacity.setter
    def legend_opacity(self, legend_opacity) -> None: ...
    @property
    def legend_orientation_threshold(self): ...
    @legend_orientation_threshold.setter
    def legend_orientation_threshold(self, legend_orientation_threshold) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
