from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class BucketsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_buckets_id(self, bucket_id, **kwargs): ...
    def delete_buckets_id_with_http_info(self, bucket_id, **kwargs): ...
    async def delete_buckets_id_async(self, bucket_id, **kwargs): ...
    def delete_buckets_id_labels_id(self, bucket_id, label_id, **kwargs): ...
    def delete_buckets_id_labels_id_with_http_info(self, bucket_id, label_id, **kwargs): ...
    async def delete_buckets_id_labels_id_async(self, bucket_id, label_id, **kwargs): ...
    def delete_buckets_id_members_id(self, user_id, bucket_id, **kwargs): ...
    def delete_buckets_id_members_id_with_http_info(self, user_id, bucket_id, **kwargs): ...
    async def delete_buckets_id_members_id_async(self, user_id, bucket_id, **kwargs): ...
    def delete_buckets_id_owners_id(self, user_id, bucket_id, **kwargs): ...
    def delete_buckets_id_owners_id_with_http_info(self, user_id, bucket_id, **kwargs): ...
    async def delete_buckets_id_owners_id_async(self, user_id, bucket_id, **kwargs): ...
    def get_buckets(self, **kwargs): ...
    def get_buckets_with_http_info(self, **kwargs): ...
    async def get_buckets_async(self, **kwargs): ...
    def get_buckets_id(self, bucket_id, **kwargs): ...
    def get_buckets_id_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_async(self, bucket_id, **kwargs): ...
    def get_buckets_id_labels(self, bucket_id, **kwargs): ...
    def get_buckets_id_labels_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_labels_async(self, bucket_id, **kwargs): ...
    def get_buckets_id_members(self, bucket_id, **kwargs): ...
    def get_buckets_id_members_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_members_async(self, bucket_id, **kwargs): ...
    def get_buckets_id_owners(self, bucket_id, **kwargs): ...
    def get_buckets_id_owners_with_http_info(self, bucket_id, **kwargs): ...
    async def get_buckets_id_owners_async(self, bucket_id, **kwargs): ...
    def get_sources_id_buckets(self, source_id, **kwargs): ...
    def get_sources_id_buckets_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_buckets_async(self, source_id, **kwargs): ...
    def patch_buckets_id(self, bucket_id, patch_bucket_request, **kwargs): ...
    def patch_buckets_id_with_http_info(self, bucket_id, patch_bucket_request, **kwargs): ...
    async def patch_buckets_id_async(self, bucket_id, patch_bucket_request, **kwargs): ...
    def post_buckets(self, post_bucket_request, **kwargs): ...
    def post_buckets_with_http_info(self, post_bucket_request, **kwargs): ...
    async def post_buckets_async(self, post_bucket_request, **kwargs): ...
    def post_buckets_id_labels(self, bucket_id, label_mapping, **kwargs): ...
    def post_buckets_id_labels_with_http_info(self, bucket_id, label_mapping, **kwargs): ...
    async def post_buckets_id_labels_async(self, bucket_id, label_mapping, **kwargs): ...
    def post_buckets_id_members(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    def post_buckets_id_members_with_http_info(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    async def post_buckets_id_members_async(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    def post_buckets_id_owners(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    def post_buckets_id_owners_with_http_info(self, bucket_id, add_resource_member_request_body, **kwargs): ...
    async def post_buckets_id_owners_async(self, bucket_id, add_resource_member_request_body, **kwargs): ...
