from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class InvokableScriptsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_scripts_id(self, script_id, **kwargs): ...
    def delete_scripts_id_with_http_info(self, script_id, **kwargs): ...
    async def delete_scripts_id_async(self, script_id, **kwargs): ...
    def get_scripts(self, **kwargs): ...
    def get_scripts_with_http_info(self, **kwargs): ...
    async def get_scripts_async(self, **kwargs): ...
    def get_scripts_id(self, script_id, **kwargs): ...
    def get_scripts_id_with_http_info(self, script_id, **kwargs): ...
    async def get_scripts_id_async(self, script_id, **kwargs): ...
    def get_scripts_id_params(self, script_id, **kwargs): ...
    def get_scripts_id_params_with_http_info(self, script_id, **kwargs): ...
    async def get_scripts_id_params_async(self, script_id, **kwargs): ...
    def patch_scripts_id(self, script_id, script_update_request, **kwargs): ...
    def patch_scripts_id_with_http_info(self, script_id, script_update_request, **kwargs): ...
    async def patch_scripts_id_async(self, script_id, script_update_request, **kwargs): ...
    def post_scripts(self, script_create_request, **kwargs): ...
    def post_scripts_with_http_info(self, script_create_request, **kwargs): ...
    async def post_scripts_async(self, script_create_request, **kwargs): ...
    def post_scripts_id_invoke(self, script_id, **kwargs): ...
    def post_scripts_id_invoke_with_http_info(self, script_id, **kwargs): ...
    async def post_scripts_id_invoke_async(self, script_id, **kwargs): ...
