from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class RestoreService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def post_restore_bucket_id(self, bucket_id, body, **kwargs): ...
    def post_restore_bucket_id_with_http_info(self, bucket_id, body, **kwargs): ...
    async def post_restore_bucket_id_async(self, bucket_id, body, **kwargs): ...
    def post_restore_bucket_metadata(self, bucket_metadata_manifest, **kwargs): ...
    def post_restore_bucket_metadata_with_http_info(self, bucket_metadata_manifest, **kwargs): ...
    async def post_restore_bucket_metadata_async(self, bucket_metadata_manifest, **kwargs): ...
    def post_restore_kv(self, body, **kwargs): ...
    def post_restore_kv_with_http_info(self, body, **kwargs): ...
    async def post_restore_kv_async(self, body, **kwargs): ...
    def post_restore_shard_id(self, shard_id, body, **kwargs): ...
    def post_restore_shard_id_with_http_info(self, shard_id, body, **kwargs): ...
    async def post_restore_shard_id_async(self, shard_id, body, **kwargs): ...
    def post_restore_sql(self, body, **kwargs): ...
    def post_restore_sql_with_http_info(self, body, **kwargs): ...
    async def post_restore_sql_async(self, body, **kwargs): ...
