from _typeshed import Incomplete

class TemplateApplyRemotes:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, url: Incomplete | None = None, content_type: Incomplete | None = None) -> None: ...
    @property
    def url(self): ...
    @url.setter
    def url(self, url) -> None: ...
    @property
    def content_type(self): ...
    @content_type.setter
    def content_type(self, content_type) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
