from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class SetupService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_setup(self, **kwargs): ...
    def get_setup_with_http_info(self, **kwargs): ...
    async def get_setup_async(self, **kwargs): ...
    def post_setup(self, onboarding_request, **kwargs): ...
    def post_setup_with_http_info(self, onboarding_request, **kwargs): ...
    async def post_setup_async(self, onboarding_request, **kwargs): ...
