from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class BucketSchemasService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def create_measurement_schema(self, bucket_id, measurement_schema_create_request, **kwargs): ...
    def create_measurement_schema_with_http_info(self, bucket_id, measurement_schema_create_request, **kwargs): ...
    async def create_measurement_schema_async(self, bucket_id, measurement_schema_create_request, **kwargs): ...
    def get_measurement_schema(self, bucket_id, measurement_id, **kwargs): ...
    def get_measurement_schema_with_http_info(self, bucket_id, measurement_id, **kwargs): ...
    async def get_measurement_schema_async(self, bucket_id, measurement_id, **kwargs): ...
    def get_measurement_schemas(self, bucket_id, **kwargs): ...
    def get_measurement_schemas_with_http_info(self, bucket_id, **kwargs): ...
    async def get_measurement_schemas_async(self, bucket_id, **kwargs): ...
    def update_measurement_schema(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs): ...
    def update_measurement_schema_with_http_info(
        self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs
    ): ...
    async def update_measurement_schema_async(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs): ...
