from _typeshed import Incomplete

class TypeWithDefault(type):
    def __init__(cls, name, bases, dct) -> None: ...
    def __call__(cls): ...
    def set_default(cls, default) -> None: ...

class Configuration(metaclass=TypeWithDefault):
    host: str
    temp_folder_path: Incomplete
    api_key: Incomplete
    api_key_prefix: Incomplete
    username: str
    password: str
    loggers: Incomplete
    logger_stream_handler: Incomplete
    logger_file_handler: Incomplete
    verify_ssl: bool
    ssl_ca_cert: Incomplete
    cert_file: Incomplete
    cert_key_file: Incomplete
    cert_key_password: Incomplete
    assert_hostname: Incomplete
    ssl_context: Incomplete
    connection_pool_maxsize: Incomplete
    timeout: Incomplete
    auth_basic: bool
    proxy: Incomplete
    proxy_headers: Incomplete
    safe_chars_for_path_param: str
    logger_formatter: Incomplete
    def __init__(self) -> None: ...
    @property
    def logger_file(self): ...
    @logger_file.setter
    def logger_file(self, value) -> None: ...
    @property
    def debug(self): ...
    @debug.setter
    def debug(self, value): ...
    @property
    def logger_format(self): ...
    @logger_format.setter
    def logger_format(self, value) -> None: ...
    def get_api_key_with_prefix(self, identifier): ...
    def get_basic_auth_token(self): ...
    def auth_settings(self): ...
    def to_debug_report(self): ...
    def update_request_header_params(self, path: str, params: dict[Incomplete, Incomplete]): ...
    def update_request_body(self, path: str, body): ...
