from _typeshed import Incomplete

class TemplateExportByIDOrgIDs:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, org_id: Incomplete | None = None, resource_filters: Incomplete | None = None) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def resource_filters(self): ...
    @resource_filters.setter
    def resource_filters(self, resource_filters) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
